0.9.9 API documentation: GLM_GTX_io

| 0.9.9 API documentation

- Main Page
- Modules
- Files

GLM_GTX_io
Experimental extensions

Include <glm/gtx/io.hpp> to use the features of this extension. More...

## Detailed Description

Include <glm/gtx/io.hpp> to use the features of this extension.

std::[w]ostream support for glm types

std::[w]ostream support for glm types + qualifier/width/etc. manipulators based on howard hinnant's std::chrono io proposal [http://home.roadrunner.com/~hinnant/bloomington/chrono_io.html]